Class: WebhookSystem::Job::ErrorResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/webhook_system/job.rb

Overview

Represents response for an exception we get when doing Faraday http call

Instance Method Summary collapse

Constructor Details

#initialize(exception) ⇒ ErrorResponse

Returns a new instance of ErrorResponse.



16
17
18
# File 'lib/webhook_system/job.rb', line 16

def initialize(exception)
  @exception = exception
end

Instance Method Details

#bodyObject



28
29
30
# File 'lib/webhook_system/job.rb', line 28

def body
  [@exception.class.name, @exception.message, *@exception.backtrace].join("\n")
end

#headersObject



24
25
26
# File 'lib/webhook_system/job.rb', line 24

def headers
  {}
end

#statusObject



20
21
22
# File 'lib/webhook_system/job.rb', line 20

def status
  0 # no HTTP response status as we got an exception while trying to perform the request
end