Module: Faraday
- Defined in:
- lib/faraday_middleware/encoding.rb
Overview
This is taken from https://github.com/ma2gedev/faraday-encoding, all credits for this goes to Takayuki Matsubara ([email protected]). We should be able to switch to the original gem when this PR (https://github.com/ma2gedev/faraday-encoding/pull/2) is merged.
Defined Under Namespace
Classes: Encoding