Class: WebhookSystem::Job
- Inherits:
-
ActiveJob::Base
- Object
- ActiveJob::Base
- WebhookSystem::Job
- Defined in:
- lib/webhook_system/job.rb
Overview
This is the ActiveJob in charge of actually sending each event
Defined Under Namespace
Classes: RequestFailed
Class Method Summary collapse
- .build_client ⇒ Object
- .build_request(client, subscription, event) ⇒ Object
- .ensure_success(response) ⇒ Object
- .log_response(subscription, event, request, response) ⇒ Object
- .post(subscription, event) ⇒ Object
Instance Method Summary collapse
Class Method Details
.build_client ⇒ Object
58 59 60 61 62 63 64 65 |
# File 'lib/webhook_system/job.rb', line 58 def self.build_client Faraday.new do |faraday| faraday.response :logger if ENV['WEBHOOK_DEBUG'] # use Faraday::Encoding middleware, libfaraday_middleware/encoding.rb faraday.response :encoding faraday.adapter Faraday.default_adapter end end |
.build_request(client, subscription, event) ⇒ Object
33 34 35 36 37 38 39 40 |
# File 'lib/webhook_system/job.rb', line 33 def self.build_request(client, subscription, event) payload = Encoder.encode(subscription.secret, event) client.build_request(:post) do |req| req.url subscription.url req.headers['Content-Type'] = 'application/json; base64+aes256' req.body = payload.to_s end end |
.ensure_success(response) ⇒ Object
26 27 28 29 30 31 |
# File 'lib/webhook_system/job.rb', line 26 def self.ensure_success(response) status = response.status unless status == 200 raise RequestFailed.new("request failed with code: #{status}", status) end end |
.log_response(subscription, event, request, response) ⇒ Object
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/webhook_system/job.rb', line 42 def self.log_response(subscription, event, request, response) event_log = EventLog.construct(subscription, event, request, response) # we write log in a separate thread to make sure it is created even if the whole job fails # Usually any background job would be wrapped into transaction, # so if the job fails we would rollback any DB changes, including the even log record. # We want the even log record to always be created, so we check if we are running inside the transaction, # if we are - we create the record in a separate thread. New Thread means a new DB connection and # ActiveRecord transactions are per connection, which gives us the "transaction jailbreak". if ActiveRecord::Base.connection.open_transactions == 0 event_log.save! else Thread.new { event_log.save! }.join end end |
.post(subscription, event) ⇒ Object
18 19 20 21 22 23 24 |
# File 'lib/webhook_system/job.rb', line 18 def self.post(subscription, event) client = build_client request = build_request(client, subscription, event) response = client.builder.build_response(client, request) log_response(subscription, event, request, response) ensure_success(response) end |
Instance Method Details
#perform(subscription, event) ⇒ Object
14 15 16 |
# File 'lib/webhook_system/job.rb', line 14 def perform(subscription, event) self.class.post(subscription, event) end |