Class: WebhookSystem::Job::ErrorResponse
- Inherits:
-
Object
- Object
- WebhookSystem::Job::ErrorResponse
- Defined in:
- lib/webhook_system/job.rb
Overview
Represents response for an exception we get when doing Faraday http call
Instance Method Summary collapse
- #body ⇒ Object
- #headers ⇒ Object
-
#initialize(exception) ⇒ ErrorResponse
constructor
A new instance of ErrorResponse.
- #status ⇒ Object
Constructor Details
#initialize(exception) ⇒ ErrorResponse
Returns a new instance of ErrorResponse.
16 17 18 |
# File 'lib/webhook_system/job.rb', line 16 def initialize(exception) @exception = exception end |
Instance Method Details
#body ⇒ Object
28 29 30 |
# File 'lib/webhook_system/job.rb', line 28 def body [@exception.class.name, @exception., *@exception.backtrace].join("\n") end |
#headers ⇒ Object
24 25 26 |
# File 'lib/webhook_system/job.rb', line 24 def headers {} end |
#status ⇒ Object
20 21 22 |
# File 'lib/webhook_system/job.rb', line 20 def status 0 # no HTTP response status as we got an exception while trying to perform the request end |